package com.digitalsanctum.webdsl.component;

import java.util.*;

/**
 * Created by IntelliJ IDEA.
 *
 * @author shane
 * @since Jul 30, 2010 11:04:58 AM
 */
public abstract class Component implements Element {

  protected static final String ATTRIBUTE_DELIM = ":";

  private String id;
  private Component parent;
  private Set<Component> children;
  private static StringBuilder sb;
  private String preMarkup;
  private String postMarkup;
  private Set<Attribute> attributes;
  private String body;

  public void setId(String id) {
    this.id = id;
  }

  public String getPreMarkup() {
    return preMarkup;
  }

  public void setPreMarkup(String preMarkup) {
    this.preMarkup = preMarkup;
  }

  public String getPostMarkup() {
    return postMarkup;
  }

  public void setPostMarkup(String postMarkup) {
    this.postMarkup = postMarkup;
  }

  public StringBuilder getBuilder() {
    if (sb == null) sb = new StringBuilder();
    return sb;
  }

  public Component getParent() {
    return parent;
  }

  public void setParent(Component parent) {
    this.parent = parent;
  }

  public Component setBody(String body) {
    this.body = body;
    return this;
  }

  public Component build() {
    StringBuilder sb = getBuilder();

    if (preMarkup != null) {
      sb.append(preMarkup);
    }

    if (hasAttributes()) {
      sb.append(getTag().open(attributes));
    } else {
      sb.append(getTag().open());
    }

    if (hasBody()) {
      sb.append(body);
    }

    if (hasChildren()) {
      for (Component c : getChildren()) {
        c.build();
      }
    }

    sb.append(getTag().close());

    if (postMarkup != null) {
      sb.append(postMarkup);
    }
    return this;
  }

  public String getMarkup() {
    build();
    return getBuilder().toString();
  }


  public Set<Component> getChildren() {
    return children;
  }

  public Component addChild(Component c) {
    if (children == null) children = new LinkedHashSet<Component>();
    c.setParent(this);
    children.add(c);
    return this;
  }

  public boolean hasChildren() {
    return children != null && !children.isEmpty();
  }

  public boolean hasParent() {
    return parent != null;
  }

  public boolean hasBody() {
    return body != null;
  }

  public String generateId() {
    return UUID.randomUUID().toString();
  }

  public String getId() {
    if (id != null) return id;
    return generateId();
  }

  public boolean hasAttributes() {
    return attributes != null && !attributes.isEmpty();
  }

  public Component addAttribute(String key, String value) {
    if (attributes == null) attributes = new LinkedHashSet<Attribute>();
    attributes.add(new Attribute(key, value));
    return this;
  }

  public Component withAttributes(String... attributes) {
    for (String attribute : attributes) {
      int pos = attribute.indexOf(ATTRIBUTE_DELIM);
      String key = attribute.substring(0, pos);
      String val = attribute.substring(pos + 1);
      addAttribute(key, val);
    }
    return this;
  }
}
