package com.digitalsanctum.webdsl.component;

import java.util.HashMap;
import java.util.Map;

/**
 * Created by IntelliJ IDEA.
 *
 * @author shane
 * @since Jul 30, 2010 10:44:42 AM
 */
public class Head extends Component {

  private static Map<String, Component> metaTags = new HashMap<String, Component>();
  private static Map<String, Link> links = new HashMap<String, Link>();
  private static Map<String, Script> scripts = new HashMap<String, Script>();

  public Tag getTag() {
    return Tag.HEAD;
  }

  public Head addMeta(Component meta) {
    metaTags.put(meta.getId(), meta);
    return this;
  }

  public Head addMeta(String... attributes) {
    Meta m = new Meta();
    m.withAttributes(attributes);
    metaTags.put(m.getId(), m);
    return this;
  }

  public Head addScript(ScriptType type, String... attributes) {
    Script s = new Script(type);
    s.withAttributes(attributes);
    scripts.put(s.getId(), s);
    return this;
  }

  public Head addStylesheet(String href) {
    Link link = new Link();
    link.withAttributes(
        "href" + ATTRIBUTE_DELIM + href,
        "rel" + ATTRIBUTE_DELIM + "stylesheet",
        "type" + ATTRIBUTE_DELIM + "text/css",
        "media" + ATTRIBUTE_DELIM + "screen, projection"
    );        
    links.put(link.getId(), link);
    return this;
  }


  public Head addScript(Script script) {
    scripts.put(script.getId(), script);
    return this;
  }

  public Head addTitle(String title) {
    addChild(new Title(title));
    return this;
  }

    

  public boolean hasMetaTags() {
    return metaTags != null && !metaTags.isEmpty();
  }

  public boolean hasScripts() {
    return scripts != null && !scripts.isEmpty();
  }

  public boolean hasLinks() {
    return links != null && !scripts.isEmpty();
  }

  public Head build() {
    if (hasMetaTags()) {
      for(Component m : metaTags.values()) {
        addChild(m);
      }
    }
    if (hasLinks()) {
      for(Link l: links.values()) {
        addChild(l);
      }
    }
    if (hasScripts()) {
      for(Script s: scripts.values()) {
        addChild(s);
      }
    }
    super.build();
    return this;
  }
}
