package com.digitalsanctum.webdsl.component;

import com.digitalsanctum.webdsl.util.StringUtils;

/**
 * Created by IntelliJ IDEA.
 *
 * @author shane
 * @since Jul 30, 2010 10:34:07 AM
 */
public class Page extends Component implements Element {

  private String title;
  private Head head;
  private Body body;

  public Page() {
    this(DocType.HTML_401_STRICT);
  }

  public Page(String title) {
    this(DocType.HTML_401_STRICT);
    addTitle(title);
  }

  public Page(DocType docType) {
    setPreMarkup(docType.getMarkup());

    head = new Head();
    addChild(head);

    body = new Body();
    addChild(body);
  }

  public Page addAnchor(Component parent, String title, String... attributes) {
    parent.addChild(new Anchor().setBody(title).withAttributes(attributes));
    body.addChild(parent);
    return this;
  }



  public Tag getTag() {
    return Tag.HTML;
  }

  public Page addP(String bodyContent) {
    body.addP(bodyContent);
    return this;
  }

  public Page addP(String bodyContent, String... attributes) {
    body.addP(bodyContent, attributes);
    return this;
  }

  public Page addDiv(String bodyContent) {
    body.addDiv(bodyContent);
    return this;
  }

  public Page addDiv(String bodyContent, String... attributes) {
    body.addDiv(bodyContent, attributes);
    return this;
  }

  public Page addMeta(Component meta) {
    head.addMeta(meta);
    return this;
  }

  public Page addMeta(String... attributes) {
    head.addMeta(attributes);
    return this;
  }

  public Page addScript(Script script) {
    head.addScript(script);
    return this;
  }

  public Page addJavaScript(String... attributes) {
    head.addScript(ScriptType.JAVASCRIPT, attributes);
    return this;
  }

  public Page addStylesheet(String href) {
    head.addStylesheet(href);
    return this;
  }

  public Page addTitle(String title) {
    this.title = title;
    head.addTitle(title);
    return this;
  }

  public String getTitle() {
      return title;
  }

  public String getFilename() {
      if (this.title != null) {
        return StringUtils.titleToFilename(this.title) + ".html";
      }
      return getId() + ".html";      
  }
}
