package com.digitalsanctum.webdsl.component;

import com.digitalsanctum.webdsl.component.Attribute;

import java.util.Set;

/**
 * Created by IntelliJ IDEA.
 *
 * @author shane
 * @since Jul 30, 2010 10:51:32 AM
 */
public enum Tag {
  A(true, true),
  BODY(true, true),
  DIV(true, true),
  HEAD(true, true),
  HTML(true, true),
  LINK(false, false),
  META(false, false),
  P(true, true),
  SCRIPT(true, true),
  SPAN(true, true),
  TITLE(true, true);

  private boolean symmetrical;
  private boolean trailingSlash;

  Tag(boolean symmetrical, boolean trailingSlash) {
    this.symmetrical = symmetrical;
    this.trailingSlash = trailingSlash;
  }

  public String open() {
    StringBuilder sb = start();
    return build(sb);
  }

  public String open(Set<Attribute> attributes) {
    StringBuilder sb = start();
    for(Attribute attrib: attributes) {
       sb.append(" ").append(attrib.getMarkup());
    }
    return build(sb);
  }

  private StringBuilder start() {
    StringBuilder sb = new StringBuilder();
    sb.append("<").append(this.name().toLowerCase());
    return sb;
  }

  private String build(StringBuilder sb) {
    if (symmetrical) {
      sb.append(">");
    } else {
      if (trailingSlash) {
        sb.append("/>");
      } else {
        sb.append(">");
      }
    }
    return sb.toString();
  }


  public String close() {
    if (!symmetrical) return "";
    StringBuilder sb = new StringBuilder();
    return sb.append("</").append(this.name().toLowerCase()).append(">").toString();
  }
}
